@@ -6,7 +6,7 @@ use warnings;
 our $VERSION;
 
 BEGIN {
-    $VERSION = '0.13_02';
+    $VERSION = '0.15_01';
 }
 
 =encoding utf-8
@@ -149,10 +149,10 @@ C<$new> is rejected with the relevant value(s).
 
 =head1 B<EXPERIMENTAL:> ASYNC/AWAIT SUPPORT
 
-This module implements L<Future::AsyncAwait::Awaitable>.
-Once you load L<Future::AsyncAwait> this lets you do nifty stuff like:
+This module is L<Promise::AsyncAwait>-compatible.
+Once you load that module you can do nifty stuff like:
 
-    use Future::AsyncAwait future_class => 'Promise::XS::Promise';
+    use Promise::AsyncAwait;
 
     async sub do_stuff {
         return 1 + await fetch_number_p();
@@ -268,6 +268,7 @@ sub use_event {
     }
 }
 
+# called from XS
 sub _convert_to_our_promise {
     my $thenable = shift;
     my $deferred= Promise::XS::Deferred::create();
@@ -297,10 +298,6 @@ sub _convert_to_our_promise {
     return $deferred->promise;
 }
 
-Promise::XS::Deferred::___set_conversion_helper(
-    \&_convert_to_our_promise,
-);
-
 #----------------------------------------------------------------------
 # Aggregator functions
 sub all {
